//
//  ViewController.swift
//  NSDictionary
//
//  Created by Keith Welch on 9/21/15.
//  Copyright © 2015 Keith Welch. All rights reserved.
//

import UIKit

class ViewController: UIViewController {

    @IBOutlet weak var outputTextView: UITextView!
    
    var masterDictionary:NSMutableDictionary!
    var detailDictionary:NSMutableDictionary!
    var documentsDirectory:NSString!

    
    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    @IBAction func btnRunTouched(sender: AnyObject) {

        // Get prepared for file I/O
        let paths:NSArray = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        documentsDirectory = paths[0] as! NSString
        
        // Create the nested dictionary structure
        masterDictionary = NSMutableDictionary()
        
        for (var i=0; i < 4; i++)
        {
            detailDictionary = NSMutableDictionary()
            detailDictionary.setValue(String(format:"Detail %d",i+1), forKey: "id")
            
            if ((i & 1) == 0) {
                detailDictionary.setValue("YES", forKey:"DetailIdIsEven")
            }
            else {
                detailDictionary.setValue("NO", forKey:"DetailIdIsEven")
            }

            let sq = i * i
            let square: NSNumber = NSNumber(integer: sq)
            detailDictionary.setValue(square, forKey:"IdSquared")
            
            masterDictionary.setValue(detailDictionary, forKey:detailDictionary.valueForKey("id") as! String)
        }
        
        // Show the master/detail dictionary before writing to file
        logToTextView(String(format:"Dictionary before writing to file:\n%@", masterDictionary.description))
        
        // Now, let's write it to a file
        let filePath:NSString = documentsDirectory.stringByAppendingPathComponent("dict.xml")
        masterDictionary.writeToFile(filePath as String, atomically:false)
        
        logToTextView("\n\n----------------------------")
        logToTextView(String(format:"File is at: %@", filePath))
        logToTextView("----------------------------\n\n")
        
        // And finally, let's read the xml file back in and verify that our NSDictionary is properly restored
        let dictionary = NSDictionary(contentsOfFile: filePath as String)
        
        logToTextView(String(format:"Dictionary from file:\n%@", dictionary!.description))
    }
    
    func logToTextView(log:String)
    {
        outputTextView.text = outputTextView.text.stringByAppendingFormat("%@\n",log)
        NSLog("%@",log)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }


}

