//
//  ViewController.swift
//  SQLiteData
//
//  Created by Keith Welch on 9/21/15.
//  Copyright © 2015 Keith Welch. All rights reserved.
//

import UIKit
import SQLite

class ViewController: UIViewController {
    
    @IBOutlet weak var outputTextView: UITextView!

    var documentsDirectory:NSString!
    var dbPath:String!
    var db:Connection!

    override func viewDidLoad() {
        super.viewDidLoad()
        
        let paths:NSArray = NSSearchPathForDirectoriesInDomains(.DocumentDirectory, .UserDomainMask, true)
        documentsDirectory = paths[0] as! NSString
        dbPath = documentsDirectory.stringByAppendingPathComponent("sample.db")
    }

    @IBAction func btnCreateTouched(sender: AnyObject) {
        do {
            db = try Connection(dbPath)
        
            let users = Table("users")
            let id = Expression<Int>("ID")
            let first_name = Expression<String?>("first_name")
            let last_name = Expression<String>("last_name")
            let username = Expression<String>("username")
            let password = Expression<String>("password")
        
        try db.run(users.create { t in
            t.column(id, primaryKey: .Autoincrement)
            t.column(first_name)
            t.column(last_name)
            t.column(username, unique: true)
            t.column(password)
            })
            
            logToTextView("Table created successfully")
        }
        catch let error as NSError {
            NSLog(error.description)
        }

    }
    
    @IBAction func btnWriteTouched(sender: AnyObject) {
        do {
            db = try Connection(dbPath)
            
            let users = Table("users")
            let first_name = Expression<String?>("first_name")
            let last_name = Expression<String>("last_name")
            let username = Expression<String>("username")
            let password = Expression<String>("password")
            
            var insert = users.insert(first_name <- "George", last_name <- "Guy", username <- "buddy@gmail.com", password <- "blues")
            var rowid = try db.run(insert)

            insert = users.insert(first_name <- "James", last_name <- "Hendricks", username <- "jimi@yahoo.com", password <- "purple")
            rowid = try db.run(insert)

            logToTextView("Inserted two users")

        }
        catch let error as NSError {
            NSLog(error.description)
        }
    }
    
    @IBAction func btnReadTouched(sender: AnyObject) {
        do {
            db = try Connection(dbPath)
            
            let users = Table("users")
            let id = Expression<Int>("ID")
            let first_name = Expression<String?>("first_name")
            let last_name = Expression<String>("last_name")
            let username = Expression<String>("username")
            let password = Expression<String>("password")
          
            
            for user in db.prepare(users) {
                logToTextView(String(format:"Read id: %d, first_name: %@, last_name: %@, username: %@, password: %@" , user[id], user[first_name]!, user[last_name], user[username], user[password]))
            }

            let james = users.filter(id == 2)
            try db.run(james.update(last_name <- "Hendrix"))
            
            let query = users.select(id, first_name, last_name)
                .filter(username == "jimi@yahoo.com")
                .order(last_name.desc, first_name)
                .limit(1, offset: 0)
            
            for user in db.prepare(query) {
                logToTextView(String(format:"Query Result id: %d, first_name: %@, last_name: %@" , user[id], user[first_name]!, user[last_name]))
            }
        }
        catch let error as NSError {
            NSLog(error.description)
        }
    }
    
    func logToTextView(log:String)
    {
        outputTextView.text = outputTextView.text.stringByAppendingFormat("%@\n",log)
        NSLog("%@",log)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
    }


}

